import setuptools

setuptools.setup(
	name= "araby-ai",
	version= "0.0.3",
	author= "VIRUS",
	description= "With this library, You can use all the services of the Araby-ai site in Python with ease",
	packages=setuptools.find_packages(),
	classifiers=[
	"Programming Language :: Python :: 3",
	"Operating System :: OS Independent",
	"License :: OSI Approved :: MIT License"
	]
)